Make Content-Length and Max-Forwards fields uints
[obnox/wireshark/wip.git] / print.c
diff --git a/print.c b/print.c
index 9c5f8f0f63c6ce11f306b2d853437b82c1e0fbef..f0fdff87224a0c8c078ca3c81d312e5910052060 100644 (file)
--- a/print.c
+++ b/print.c
@@ -5,8 +5,8 @@
  *
  * Gilbert Ramirez <gram@alumni.rice.edu>
  *
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
  *
  * This program is free software; you can redistribute it and/or
@@ -39,6 +39,7 @@
 #include "packet-range.h"
 #include "print.h"
 #include "ps.h"
+#include "file_util.h"
 #include <epan/charsets.h>
 #include <epan/dissectors/packet-data.h>
 #include <epan/dissectors/packet-frame.h>
@@ -83,7 +84,7 @@ open_print_dest(int to_file, const char *dest)
 
        /* Open the file or command for output */
        if (to_file)
-               fh = fopen(dest, "w");
+               fh = eth_fopen(dest, "w");
        else
                fh = popen(dest, "w");
 
@@ -153,11 +154,19 @@ void proto_tree_print_node(proto_node *node, gpointer data)
                proto_item_fill_label(fi, label_str);
        }
 
+    if(PROTO_ITEM_IS_GENERATED(node)) {
+        label_ptr = g_strdup_printf("[%s]", label_ptr);
+    }
+
        if (!print_line(pdata->stream, pdata->level, label_ptr)) {
                pdata->success = FALSE;
                return;
        }
 
+    if(PROTO_ITEM_IS_GENERATED(node)) {
+        g_free(label_ptr);
+    }
+
        /* If it's uninterpreted data, dump it (unless our caller will
           be printing the entire packet in hex). */
        if (fi->hfinfo->id == proto_data && pdata->print_hex_for_data) {
@@ -228,7 +237,7 @@ proto_tree_write_node_pdml(proto_node *node, gpointer data)
 {
        field_info      *fi = PITEM_FINFO(node);
        write_pdml_data *pdata = (write_pdml_data*) data;
-       gchar           *label_ptr;
+       const gchar     *label_ptr;
        gchar           label_str[ITEM_LABEL_LENGTH];
        char            *dfilter_string;
        int             chop_len;
@@ -346,7 +355,15 @@ proto_tree_write_node_pdml(proto_node *node, gpointer data)
                        }
                        if (fi->length > 0) {
                                fputs("\" value=\"", pdata->fh);
-                               write_pdml_field_hex_value(pdata, fi);
+
+                               if (fi->hfinfo->bitmask!=0) {
+                                       fprintf(pdata->fh, "%X", fvalue_get_integer(&fi->value));
+                                       fputs("\" unmaskedvalue=\"", pdata->fh);
+                                       write_pdml_field_hex_value(pdata, fi);
+                               }
+                               else {
+                    write_pdml_field_hex_value(pdata, fi);
+                }
                        }
                }
 
@@ -383,7 +400,7 @@ proto_tree_write_node_pdml(proto_node *node, gpointer data)
 }
 
 /* Print info for a 'geninfo' pseudo-protocol. This is required by
* the PDML spec. The information is contained in Ethereal's 'frame' protocol,
  * but we produce a 'geninfo' protocol in the PDML to conform to spec.
  * The 'frame' protocol follows the 'geninfo' protocol in the PDML. */
 static void
@@ -513,6 +530,37 @@ write_psml_finale(FILE *fh)
        fputs("</psml>\n", fh);
 }
 
+void
+write_csv_preamble(FILE *fh _U_)
+{
+
+}
+
+void
+proto_tree_write_csv(epan_dissect_t *edt, FILE *fh)
+{
+        gint    i;
+
+        /* if this is the first packet, we have to write the CSV header */
+        if(edt->pi.fd->num == 1) {
+            for(i=0; i < edt->pi.cinfo->num_cols - 1; i++)
+               fprintf(fh, "\"%s\", ", edt->pi.cinfo->col_title[i]);
+
+            fprintf(fh, "\"%s\"\n", edt->pi.cinfo->col_title[i]);
+        }
+
+        for(i=0; i < edt->pi.cinfo->num_cols - 1; i++)
+            fprintf(fh, "\"%s\", ", edt->pi.cinfo->col_data[i]);
+
+        fprintf(fh, "\"%s\"\n", edt->pi.cinfo->col_data[i]);
+}
+
+void
+write_csv_finale(FILE *fh _U_)
+{
+
+}
+
 /*
  * Find the data source for a specified field, and return a pointer
  * to the data in it. Returns NULL if the data is out of bounds.
@@ -640,6 +688,8 @@ print_hex_data(print_stream_t *stream, epan_dissect_t *edt)
                        g_free(line);
                }
                length = tvb_length(tvb);
+               if (length == 0)
+                   return TRUE;
                cp = tvb_get_ptr(tvb, 0, length);
                if (!print_hex_data_buffer(stream, cp, length,
                    edt->pi.fd->flags.encoding))
@@ -652,7 +702,7 @@ print_hex_data(print_stream_t *stream, epan_dissect_t *edt)
  * This routine is based on a routine created by Dan Lasley
  * <DLASLEY@PROMUS.com>.
  *
- * It was modified for Ethereal by Gilbert Ramirez and others.
+ * It was modified for Wireshark by Gilbert Ramirez and others.
  */
 
 #define MAX_OFFSET_LEN 8       /* max length of hex offset of bytes */
@@ -956,7 +1006,7 @@ print_preamble_ps(print_stream_t *self, gchar *filename)
        fputs("\n", output->fh);
        fputs("%% the page title\n", output->fh);
        ps_clean_string(psbuffer, filename, MAX_PS_LINE_LENGTH);
-       fprintf(output->fh, "/eth_pagetitle (%s - Ethereal) def\n", psbuffer);
+       fprintf(output->fh, "/eth_pagetitle (%s - Wireshark) def\n", psbuffer);
        fputs("\n", output->fh);
        return !ferror(output->fh);
 }
@@ -5,8 +5,8 @@
  * Gilbert Ramirez <gram@alumni.rice.edu>
  *
- * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@ethereal.com>
+ * Wireshark - Network traffic analyzer
+ * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
@@ -383,7 +400,7 @@ proto_tree_write_node_pdml(proto_node *node, gpointer data)
 
 /* Print info for a 'geninfo' pseudo-protocol. This is required by
- * the PDML spec. The information is contained in Ethereal's 'frame' protocol,
+ * the PDML spec. The information is contained in Wireshark's 'frame' protocol,
  * but we produce a 'geninfo' protocol in the PDML to conform to spec.
  * The 'frame' protocol follows the 'geninfo' protocol in the PDML. */